.. python-eduvpn-client documentation master file, created by
   sphinx-quickstart on Wed Aug  2 15:37:37 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to python-eduvpn-client's documentation!
================================================

This is the documentation for the GNU/Linux desktop client and Python API for eduVPN. The Desktop client only works on
Linux, but the command-line interface and most parts of the API are usable on other platforms also. Python 3.6+ is
required.


.. toctree::
   :maxdepth: 2
   :caption: Contents:

   installation
   usage
   developer


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
